#synthDrivers/_eloquence.py
#A part of NonVisual Desktop Access (NVDA)
#Copyright (C) 2006-2008 NVDA Contributors <http://www.nvda-project.org/>
#This file is covered by the GNU General Public License.
#See the file COPYING for more details.

import os
from ctypes import *
import languageHandler

Handle=None
Tts=None
LastIndex=None
NvdaDir=os.getcwd()
NvdaSynthDir=NvdaDir+'\\synthDrivers'
CurrentVoice=1
Pitch=2
pitchFluctuation=3
Speed=6
Volume=7
CurrentLang=1
maxAvailableLangs=[
		('enu',('American English',0x10000,'en')),
		('eng',('British English',0x10001,'en')),
		('esp',('Castilian Spanish',0x20000,'es_es')),
		('esm',('Latin Amnerican Spanish',0x20001,'es_es')),
		('fra',('French',0x30000,'fr')),
		('frc',('French Canadian',0x30001,'fr')),
		('deu',('German',0x40000,'de')),
		('ita',('Italian',0x50000,'it_it')),
		('ptb',('Brazilian Portuguese',0x70000,'pt_br')),
		('fin',('Finnish',0x90000,'fi'))]
Lang=[]
LangCount=1

#Tts parameters constants
minRate=0
maxRate=250
InputType=1
Language=9

def check():
	global Lang
	try:
		os.chdir(NvdaSynthDir)
		dll=windll.LoadLibrary("Library_rtts.dll")
		if dll.mCK(): 
			Lang=[]
			del dll
			os.chdir(NvdaDir)
			return True
		else:
			os.chdir(NvdaDir)			
	except:
		os.chdir(NvdaDir)
	return False


def getAvailableLangs():
	global Lang
	availableSyn=[]
	[availableSyn.append(name[:-4].lower()) for name in os.listdir(NvdaSynthDir) if name.lower().endswith('.syn')]
	[Lang.append(item[1]) for item in maxAvailableLangs if item[0] in availableSyn]
	return len(Lang)


def setDefaultLang():
	lang=languageHandler.getLanguage()
	if lang.lower()=='pt_pt': lang='pt_br'
	for num in range(len(maxAvailableLangs)):
		if lang.lower() in maxAvailableLangs[num][1]: 
			TtsSetLang(num+1) 
			break


def TtsOpen():
	global Handle, Tts, LangCount
	os.chdir(NvdaSynthDir)
	Tts=windll.LoadLibrary("Library_rtts.dll")
	Handle=Tts.mNW()
	os.chdir(NvdaDir)
	LangCount=getAvailableLangs()

def TtsGetLastIndex():
	return Tts.mGI(Handle)


def TtsSpeak(text, index=None):
	Tts.mAT(Handle, c_char_p(text))
	if index is not None: Tts.mII(Handle, index)
	Tts.mSZ(Handle)


def TtsPause():
	Tts.mPE(Handle, True)


def TtsRestart():
	Tts.mPE(Handle, False)


def TtsStop():
	Tts.mST(Handle)


def TtsSetParam(param, value):
	Tts.mSV(Handle, 0, param, value)


def TtsGetParam(param):
	return Tts.mGV(Handle, 0, param)


def TtsSetVoice(num):
	global CurrentVoice
	if num>8: num=1
	tempSpeed=TtsGetParam(Speed)
	tempPitch=TtsGetParam(Pitch)
	tempVolume=TtsGetParam(Volume)
	voiceTag=' `v'+str(num)+' `da0 `vs'+str(tempSpeed)+' `vb'+str(tempPitch)+' `vv'+str(tempVolume)
	Tts.mSP(Handle,  InputType, 1)
	Tts.mAT(Handle, voiceTag)
	Tts.mSZ(Handle)
	Tts.mSP(Handle,  InputType, 0)
	CurrentVoice=num


def TtsSetLang(num):
	global CurrentLang
	if num>LangCount: num=1
	lng=Lang[num-1][1]
	Tts.mSP(Handle, Language, lng)
	CurrentLang=num


def TtsGetVariantNames():
	Voices={}
	for num in range(1,9):
		name=create_string_buffer(30)
		Tts.mGN(Handle, num, name)
		Voices[num]=name.value
	Voices['9']=_('None')
	return Voices


def TtsClose():
		global Handle, Tts
		TtsStop()
		Tts.mDT(Handle)
		Handle=None



