#synthDrivers/eloquence.py
#A part of NonVisual Desktop Access (NVDA)
#Copyright (C) 2006-2008 NVDA Contributors <http://www.nvda-project.org/>
#This file is covered by the GNU General Public License.
#See the file COPYING for more details.


import _eloquence
import synthDriverHandler
import _winreg

class SynthDriver(synthDriverHandler.SynthDriver):

	hasVoice=True
	hasPitch=True
	hasRate=True
	hasVolume=True
	hasVariant=True
	hasInflection=True

	description=_("ETI-Eloquence")
	name="eloquence"


	@classmethod
	def check(cls):
		return _eloquence.check()


	def _paramToPercent(self, current, min, max):
		return int(round(float(current - min) / (max - min) * 100))


	def _percentToParam(self, percent, min, max):
		return int(round(float(percent) / 100 * (max - min) + min))


	def initialize(self):
		try:
			_eloquence.TtsOpen()
			self._variantDict=_eloquence.TtsGetVariantNames()
			self.variant="Adult Male"
			_eloquence.setDefaultLang()
			return True 
		except:
			return False 


	def terminate(self):
		_eloquence.TtsClose()


	def _get_lastIndex(self):
		return _eloquence.TtsGetLastIndex()
 

	def speakText(self,text,index=None):
		_eloquence.TtsSpeak(text,  index=index)


	def pause(self,switch):
		if switch: 
		   _eloquence.TtsPause()
		else:
		   _eloquence.TtsRestart()


	def cancel(self):
		_eloquence.TtsStop()


	def _get_voiceCount(self):
		return _eloquence.LangCount


	def getVoiceName(self, num):
		return _eloquence.Lang[num-1][0] 


	def _get_variant(self):
		return self._variant 


	def _set_variant(self, val):
		self._variant = val if val in self._variantDict else "Adult Male 1"
		_eloquence.TtsSetVoice(val) 


	def _get_variantCount(self):
		return 9 


	def getVariantName(self, num):
		return self._variantDict.values()[num]


	def getVariantIdentifier(self,num):
		return self._variantDict.keys()[num]


	def _get_voice(self):
		return _eloquence.CurrentLang


	def _set_voice(self, val):
				_eloquence.TtsSetLang(val)


	def _get_rate(self):
		val=_eloquence.TtsGetParam(_eloquence.Speed) 
		return self._paramToPercent(val, _eloquence.minRate, _eloquence.maxRate) 


	def _set_rate(self,value):
		val=self._percentToParam(value, _eloquence.minRate, _eloquence.maxRate)
		_eloquence.TtsSetParam(_eloquence.Speed, val)


	def _get_pitch(self):
		return _eloquence.TtsGetParam(_eloquence.Pitch) 


	def _get_inflection(self):
		return _eloquence.TtsGetParam(_eloquence.pitchFluctuation) 


	def _set_pitch(self,value):
		_eloquence.TtsSetParam(_eloquence.Pitch,value)


	def _set_inflection(self,value):
		_eloquence.TtsSetParam(_eloquence.pitchFluctuation,value)


	def _get_volume(self):
		return _eloquence.TtsGetParam(_eloquence.Volume)


	def _set_volume(self,value):
		_eloquence.TtsSetParam(_eloquence.Volume, value)


